@@ -1,7 +1,7 @@
 import os
 import json
 
-refdata = os.path.abspath(os.path.dirname(__file__)+'../refdata') + '/'
+refdata = os.path.abspath(os.path.dirname(__file__)+'/../refdata') + '/'
 
 def get_telescope_config():
 
@@ -29,9 +29,11 @@ def get_instrument_config():
     dict['readout_xbin'] = 1
     dict['readout_ybin'] = 1
     dict['gain'] = 1                            # e/ADU
+
     dict['dark'] = 0.017                        # e/s/pix
     dict['readout_noise'] = 4.0                 # e/pix
-    dict['QE'] = 1.0                            # e/pix
+    dict['QE'] = 1.0
+
     dict['efficiency_file'] = 'IFU_throughput.dat'
 
     # out_file = open(refdata + "csst/ifs/config.json", "w")
